@@ -62,7 +62,7 @@ def select_salient_posts(post_vectors,post_weights,k = 10,similarity_threshold =
             significant_indices.append(i)
             unsorted_indices.append(sorted_keyed_vectors[i][0])
 
-        if (len(significant_indices) >= k) or (i >= veclength) :
+        if (len(significant_indices) >= k) or (i >= veclength-1) :
             loop_condition = False
         i+=1
     
